package de.hsel.itech.servlet;

import de.hsel.itech.db.Database;
import de.hsel.itech.db.pojo.Author;
import de.hsel.itech.db.pojo.Book;
import de.hsel.itech.db.pojo.Category;
import de.hsel.itech.db.pojo.Publisher;

import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.PrintWriter;
import java.nio.charset.StandardCharsets;
import java.time.Year;
import java.util.ArrayList;
import java.util.List;

public class BookList extends HttpServlet {

    protected void doGet(final HttpServletRequest req, final HttpServletResponse resp)
            throws IOException {
        req.setCharacterEncoding(StandardCharsets.UTF_8.name());

        //get database object
        Database db = Database.getInstance();

        //print parameters (debug)
        /*Enumeration<String> names = req.getParameterNames();
        while (names.hasMoreElements()) {
            String name = names.nextElement();
            System.out.println(name + "=" + req.getParameter(name));
        }*/

        //remove book by id
        String param = req.getParameter("removeid");
        if (param != null && Long.parseLong(param) != 0) {
            long isbn = Long.parseLong(param);
            db.deleteBook(isbn);
            resp.sendRedirect("booklist");
        }

        if (req.getParameter("title") != null) {
            long isbn = Long.parseLong(req.getParameter("isbn"));
            String title = req.getParameter("title");
            String authorName = req.getParameter("author");
            int price = Integer.parseInt(req.getParameter("price"));
            int year = Integer.parseInt(req.getParameter("year"));
            String categoryName = req.getParameter("category");
            String description = req.getParameter("description");
            String publisher = req.getParameter("publisher");
            String image = req.getParameter("image");


            ArrayList<Author> authors = new ArrayList<>();
            String[] authorNames = authorName.split(",");
            for (String name : authorNames) {
                authors.add(new Author(name));
            }
            Category category = new Category();
            category.setName(categoryName);
            Book book = new Book(isbn,
                    authors,
                    new Publisher(publisher),
                    category,
                    title, Year.of(year), price, description, image
            );
            db.insert(book);

            resp.sendRedirect("booklist");
        }

        resp.setCharacterEncoding("utf-8");
        PrintWriter out = resp.getWriter();

        //header template
        Utillity.insertFile(out, "template_head.html");


        List<Book> books = db.getBooks();

        if (books != null) {

            //book entries
            out.println("<div class=\"m-container\">");
            for (Book book : books) {

                out.println(" <div class=\"m-row\">");

                out.println("  <div class=\"m-col-l-4\">");
                out.println("   <img class=\"m-image\" src=\"https://source.unsplash.com/" + book.getImage() + "/300x300\" alt=\"Buchcover\">");
                out.println("  </div>");

                out.println("  <div class=\"m-col-l-4\">");
                out.println("<h1>" + book.getTitle() + "</h1>");
                out.println("   <br>");
                for (int i = 0; i < book.getAuthors().size(); i++) {
                    out.println("   <h2>" + book.getAuthors().get(0).getName() + "</h2>");
                }
                out.println("   <br>");
                out.print("   <h3>" + book.getPrice() / 100 + ",");
                if (book.getPrice() % 100 < 10) {
                    out.print("0");
                }
                out.println(book.getPrice() % 100 + " &euro;</h3>");
                out.println("   <br>");
                out.println("  </div>");

                out.println("  <div class=\"m-col-l-4\">");
                out.println("   <div class=\"m-button m-danger\">");

                out.println("<a href=\"/itech/booklist?removeid=" + book.getId() + "\">");
                out.println("Entfernen");
                out.println("</a>");

                out.println(" </div>");
                out.println("   </div>");
                out.println("  </div>");
            }
            out.println("</div>");
        }

        //add book button
        Utillity.addButton(out, "Neues Buch Hinzufügen", "addbook");

        //footer template
        Utillity.insertFile(out, "template_footer.html");
    }

    protected void doPost(final HttpServletRequest req, final HttpServletResponse resp)
            throws IOException {
        doGet(req, resp);
    }

}
